//
// soft synth test
//
// Ql : http://kioku.sys-k.net/tips/lec6.html
//
#include <stdio.h>
#include <math.h>
#include <stdlib.h>
#include <ctype.h>
#include <windows.h>

//lib
#pragma comment(lib,"user32")
#pragma comment(lib,"winmm")

//def
#define SND_PI             (3.141592653589793f)
#define SND_NOTE_DT        (1.059463100070972f)
#define SND_NOTE_BASE      (8.0f / (float)SND_SAMPLES)
#define SND_BITS           16
#define SND_SAMPLES        (44100)
//#define SND_SAMPLES        (44100/2)
#define SND_SAMPLE_DIV     8
#define SND_SAMPLE_UNIT    (SND_SAMPLES / SND_SAMPLE_DIV)
#define SND_SAMPLES_DT     (1.0f / (float)SND_SAMPLES);
#define SND_CH             2
#define SND_TRACK_MAX      16
#define SND_SEC            60 * 3
#define SND_LENGTH         (SND_CH * SND_SAMPLES * SND_SEC)
#define SND_UNIT_NUM       ( (SND_LENGTH / SND_CH) / SND_SAMPLE_UNIT )
#define SND_TYPE           float
#define SND_CODE_END       0xFF
#define SND_CODE_CUT       0x7F
#define SND_MAX_TH         0.95f

//global data
static HWAVEOUT hWOut = NULL;
static WAVEFORMATEX wf;
static WAVEHDR wh;
static SND_TYPE canvas[SND_LENGTH];
static SND_TYPE raw_buffer[SND_LENGTH];

//sound ch
struct SND_TRACK {
  int   type;
  float  t;
  float dt;
  float gain;
  float dgain;
};
SND_TRACK snd_track[SND_TRACK_MAX];

//
void snd_set_track(int ch, int type, float gain, float dgain) {
  if(ch < SND_TRACK_MAX) {
    SND_TRACK *w = &(snd_track[ch]);
    w->type = type;
    w->t  = 0;
    w->dt = 0;
    w->gain = gain;
    w->dgain = dgain;
  }
}

//rand : noiseŎg
float snd_rand() {
  return (float)(rand() / 32767.0f);
}

//round
float snd_round(float a) {
  return (float)(int)(a + 0.5f);
}

//sound terminate
void snd_term() {
  if(hWOut) {
    waveOutClose(hWOut);
    hWOut = NULL;
  }
  memset(canvas, 0, sizeof(canvas));
  memset(raw_buffer, 0, sizeof(raw_buffer));
  memset(snd_track, 0, sizeof(snd_track));
}

//reset
void snd_reset() {
  snd_term();
}

//mix
void snd_mix(float gain) {
  for(int i = 0 ; i < SND_LENGTH ; i++) {
    raw_buffer[i] += (canvas[i] * gain);
  }
}

//set snd_global_vol
void snd_global_vol(float gain) {
  for(int i = 0 ; i < SND_LENGTH ; i++) {
    raw_buffer[i] *= gain;
  }
}

//Low pass
void snd_low_pass(float k) {
  for(int i = SND_CH ; i < SND_LENGTH ; i += SND_CH) {
    canvas[i] = canvas[i] + ((canvas[i - SND_CH] - canvas[i]) * k);
    if(SND_CH == 2) {
      canvas[i + 1] = canvas[i + 1] + ((canvas[i - SND_CH + 1] - canvas[i + 1]) * k);
    }
  }
}

//High pass
void snd_high_pass(float k) {
  for(int i = SND_CH ; i < SND_LENGTH ; i += SND_CH) {
    canvas[i] = canvas[i] - canvas[i - SND_CH] * k;
    if(SND_CH == 2) {
      canvas[i + 1] = canvas[i + 1] - canvas[i - SND_CH + 1] * k;
    }
  }
}

//Delay
void snd_delay(int t, float k) {
  for(int i = t ; i < SND_LENGTH ; i += SND_CH) {
    canvas[i] = canvas[i] + (canvas[i - t] * k);
    if(SND_CH == 2) {
      canvas[i + 1] = canvas[i + 1] + (canvas[i - t + 1] * k);
    }
  }
}

//Compressor
void snd_comp(int t, float th, float ratio, float gain) {
  for(int i = t ; i < SND_LENGTH ; i++) {
    //unsigned long sign = (*(unsigned long *)(&canvas[i])) & 0x80000000;
    float         vol  = canvas[i];
    unsigned long sign = (vol < 0 ? 1 : 0);
    
    vol  = (vol < 0 ? -vol : vol);
    if(vol >= th ) {
      vol *= ratio;
    } else {
      vol *= gain;
    }
    if(sign) vol = -vol;
    canvas[i] = vol;
  }
}

//Float -> to int
void snd_convert() {
  if(SND_BITS != 16) {
    MessageBox(NULL, "Error", "Not support sound bits", MB_OK);
    return;
  }
  
  snd_comp(0, 0.4, 0.9, 1.02);
  
  short *buf = (short *)raw_buffer;
  for(int i = 0 ; i < SND_LENGTH ; i++) {
    float vol = raw_buffer[i] * 32767.0f;
    float th = SND_MAX_TH;
    vol = (vol > th) ? th : (vol < -th) ? -th : vol;
    buf[i] = (short)(raw_buffer[i] * 32767.0f);
  }
}

float snd_get_note(int note) {
  float dt = SND_NOTE_BASE * SND_NOTE_DT;
  for(int i = 0 ; i < note; i++) {
    dt *= SND_NOTE_DT;
  }
  
  return dt;
}

void snd_render_track(int ch, unsigned char *data, float ch_vol, float gain_l, float gain_r, float detune) {
  if(ch > SND_TRACK_MAX) return;
  printf("Render Track ch[%d]\n", ch);
  SND_TRACK *w = &(snd_track[ch]);
  memset(canvas, 0, sizeof(canvas));
  float *buf = canvas;
  float drum_dt  = (ch >= 10) ? 0.9999 : 1;
  float t  = 0;
  float dt = 0;
  float gain = 0;
  float dgain = (ch >= 10) ? 0.9995 : 0.99993;
  for(int n = 0 ; n < SND_UNIT_NUM ; n++, buf += (SND_SAMPLE_UNIT * SND_CH) ) {
    int note = data[n];
    if(note == SND_CODE_END) break;
    if(note == SND_CODE_CUT) {
      dt = 0;
      t  = 0;
      continue;
    }
    if(note != 0x00) {
      t  = 0;
      dt = snd_get_note(note) * detune;
      gain = 1;
    }
    if(note != 0   ) t = 0;
    for(int i = 0 ; i < SND_SAMPLE_UNIT * SND_CH; i += SND_CH) {
      dt *= drum_dt;
      t += dt;
      t -= snd_round(t);
      float v = 0;
      switch(ch) {
        case 0: {
          v = sin( (2 * t * SND_PI) / SND_PI);
          break;
        }
        case 1: {
#if 1
          float gk = 0.4f;
          float fm = sin(t * SND_PI * 2 * gk) * 2 + sin(t * SND_PI * 2 * gk);
          v = sin( (t * SND_PI * 2) + fm);
          v -= sin( (t * SND_PI * 0.02) + fm);
          
          //ނ̂΂
          gain += 0.00002;
#else
          float fm = sin(t * SND_PI * 2 * 0.4) * 2 + sin(t * SND_PI * 2 * 0.4);
          v = sin( (t * SND_PI * 7) + fm);
          v -= sin( (t * SND_PI * 0.5) + fm);
#endif
          break;
        }
        case 2: {
          v  = (t <= 0.2) ? 1 : -1;
          break;
        }
        case 3: {
          v = sin(2 * SND_PI * t);
          v = sin(v);
          break;
        }
        case 10: {
          v = sin(t * 2 * SND_PI + (snd_rand() * 0.1));
          break;
        }
        case 11: {
          v = sin(snd_rand());
          break;
        }
      default:
        v = sin(2 * SND_PI * t);
        break;
      }
      buf[i    ] = v * gain * gain_l;
      buf[i + 1] = v * gain * gain_r;
      gain *= dgain;
    }
  }
  
  //Ă݂
  snd_delay(15000,  0.3);
  snd_delay(25000,  0.3);
  
  if(ch == 11) {
    snd_low_pass(0.2);
  }
  snd_mix(ch_vol);
}

//Play Sound
void snd_play() {
  //convert float -> short
  snd_convert();
  
  //play sound
  memset(&wf, 0, sizeof(wf));
  wf.wFormatTag      = WAVE_FORMAT_PCM;
  wf.nChannels       = SND_CH;
  wf.nSamplesPerSec  = SND_SAMPLES;
  wf.wBitsPerSample  = SND_BITS;
  wf.nBlockAlign     = wf.nChannels * wf.wBitsPerSample / 8;
  wf.nAvgBytesPerSec = wf.nSamplesPerSec * wf.nBlockAlign;
  wf.cbSize          = 0;
  waveOutOpen(&hWOut, WAVE_MAPPER, &wf, 0, 0, CALLBACK_NULL);
  
  memset(&wh, 0, sizeof(wh));
  wh.lpData          = (LPSTR)raw_buffer;
  wh.dwBufferLength  = SND_LENGTH * (wf.wBitsPerSample / 8);
  wh.dwFlags         = 0;
  wh.dwLoops         = 1;
  wh.dwBytesRecorded = 0;
  wh.dwUser          = 0;
  wh.lpNext          = NULL;
  wh.reserved        = 0;
  waveOutPrepareHeader(hWOut , &wh , sizeof(WAVEHDR));
  waveOutWrite(hWOut , &wh , sizeof(WAVEHDR));
}


//ep
int main() {
  snd_reset();
  
  static unsigned char data1[] = {
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x3A, 0x00, 0x00, 0x3A,  0x00, 0x00, 0x3A, 0x00, 
    0x7F, 0x00, 0x3C, 0x00,  0x00, 0x3C, 0x00, 0x00,  0x3C, 0x00, 0x00, 0x3C,  0x00, 0x00, 0x3C, 0x00, 
    0x7F, 0x00, 0x3D, 0x00,  0x00, 0x3D, 0x00, 0x00,  0x3D, 0x00, 0x00, 0x3D,  0x00, 0x00, 0x3D, 0x00, 
    0x7F, 0x00, 0x3C, 0x00,  0x00, 0x3C, 0x00, 0x00,  0x3C, 0x00, 0x00, 0x3C,  0x00, 0x00, 0x3C, 0x00, 
    
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x3A, 0x00, 0x00, 0x3A,  0x00, 0x00, 0x3A, 0x00, 
    0x7F, 0x00, 0x3C, 0x00,  0x00, 0x3C, 0x00, 0x00,  0x3C, 0x00, 0x00, 0x3C,  0x00, 0x00, 0x3C, 0x00, 
    0x7F, 0x00, 0x3D, 0x00,  0x00, 0x3D, 0x00, 0x00,  0x3D, 0x00, 0x00, 0x3D,  0x00, 0x00, 0x3D, 0x00, 
    0x7F, 0x00, 0x3C, 0x00,  0x00, 0x3C, 0x00, 0x00,  0x3C, 0x00, 0x00, 0x3C,  0x00, 0x00, 0x3C, 0x00, 

    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x3A, 0x00, 0x00, 0x3A,  0x00, 0x00, 0x3A, 0x00, 
    0x7F, 0x00, 0x3C, 0x00,  0x00, 0x3C, 0x00, 0x00,  0x3C, 0x00, 0x00, 0x3C,  0x00, 0x00, 0x3C, 0x00, 
    0x7F, 0x00, 0x3D, 0x00,  0x00, 0x3D, 0x00, 0x00,  0x3D, 0x00, 0x00, 0x3D,  0x00, 0x00, 0x3D, 0x00, 
    0x7F, 0x00, 0x3C, 0x00,  0x00, 0x3C, 0x00, 0x00,  0x3C, 0x00, 0x00, 0x3C,  0x00, 0x00, 0x3C, 0x00, 
    
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x3A, 0x00, 0x00, 0x3A,  0x00, 0x00, 0x3A, 0x00, 
    0x7F, 0x00, 0x3C, 0x00,  0x00, 0x3C, 0x00, 0x00,  0x3C, 0x00, 0x00, 0x3C,  0x00, 0x00, 0x3C, 0x00, 
    0x7F, 0x00, 0x3D, 0x00,  0x00, 0x3D, 0x00, 0x00,  0x3D, 0x00, 0x00, 0x3D,  0x00, 0x00, 0x3D, 0x00, 
    0x7F, 0x00, 0x3C, 0x00,  0x00, 0x3C, 0x00, 0x00,  0x3C, 0x00, 0x00, 0x3C,  0x00, 0x00, 0x3C, 0x00, 
    
    
    
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x3A, 0x00, 0x00, 0x3A,  0x00, 0x00, 0x3A, 0x00, 
    0x7F, 0x00, 0x3C, 0x00,  0x00, 0x3C, 0x00, 0x00,  0x3C, 0x00, 0x00, 0x3C,  0x00, 0x00, 0x3C, 0x00, 
    0x7F, 0x00, 0x3D, 0x00,  0x00, 0x3D, 0x00, 0x00,  0x3D, 0x00, 0x00, 0x3D,  0x00, 0x00, 0x3D, 0x00, 
    0x7F, 0x00, 0x3C, 0x00,  0x00, 0x3C, 0x00, 0x00,  0x3C, 0x00, 0x00, 0x3C,  0x00, 0x00, 0x3C, 0x00, 

    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x3A, 0x00, 0x00, 0x3A,  0x00, 0x00, 0x3A, 0x00, 
    0x7F, 0x00, 0x3C, 0x00,  0x00, 0x3C, 0x00, 0x00,  0x3C, 0x00, 0x00, 0x3C,  0x00, 0x00, 0x3C, 0x00, 
    0x7F, 0x00, 0x3D, 0x00,  0x00, 0x3D, 0x00, 0x00,  0x3D, 0x00, 0x00, 0x3D,  0x00, 0x00, 0x3D, 0x00, 
    0x7F, 0x00, 0x3C, 0x00,  0x00, 0x3C, 0x00, 0x00,  0x3C, 0x00, 0x00, 0x3C,  0x00, 0x00, 0x3C, 0x00, 
    
    
    //torinouta
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x3A, 0x00, 0x00, 0x3A,  0x00, 0x00, 0x3A, 0x00, 
    0x7F, 0x00, 0x3C, 0x00,  0x00, 0x3C, 0x00, 0x00,  0x3C, 0x00, 0x00, 0x3C,  0x00, 0x00, 0x3C, 0x00, 
    0x7F, 0x00, 0x3D, 0x00,  0x00, 0x3D, 0x00, 0x00,  0x3D, 0x00, 0x00, 0x3D,  0x00, 0x00, 0x3D, 0x00, 
    0x7F, 0x00, 0x3C, 0x00,  0x00, 0x3C, 0x00, 0x00,  0x3C, 0x00, 0x00, 0x3C,  0x00, 0x00, 0x3C, 0x00, 

    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x3A, 0x00, 0x00, 0x3A,  0x00, 0x00, 0x3A, 0x00, 
    0x7F, 0x00, 0x3C, 0x00,  0x00, 0x3C, 0x00, 0x00,  0x3C, 0x00, 0x00, 0x3C,  0x00, 0x00, 0x3C, 0x00, 
    0x7F, 0x00, 0x3D, 0x00,  0x00, 0x3D, 0x00, 0x00,  0x3D, 0x00, 0x00, 0x3D,  0x00, 0x00, 0x3D, 0x00, 
    0x7F, 0x00, 0x3C, 0x00,  0x00, 0x3C, 0x00, 0x00,  0x3C, 0x00, 0x00, 0x3C,  0x00, 0x00, 0x3C, 0x00, 
    
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x3A, 0x00, 0x00, 0x3A,  0x00, 0x00, 0x3A, 0x00, 
    0x7F, 0x00, 0x3C, 0x00,  0x00, 0x3C, 0x00, 0x00,  0x3C, 0x00, 0x00, 0x3C,  0x00, 0x00, 0x3C, 0x00, 
    0x7F, 0x00, 0x3D, 0x00,  0x00, 0x3D, 0x00, 0x00,  0x3D, 0x00, 0x00, 0x3D,  0x00, 0x00, 0x3D, 0x00, 
    0x7F, 0x00, 0x3C, 0x00,  0x00, 0x3C, 0x00, 0x00,  0x3C, 0x00, 0x00, 0x3C,  0x00, 0x00, 0x3C, 0x00, 

    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x3A, 0x00, 0x00, 0x3A,  0x00, 0x00, 0x3A, 0x00, 
    0x7F, 0x00, 0x3C, 0x00,  0x00, 0x3C, 0x00, 0x00,  0x3C, 0x00, 0x00, 0x3C,  0x00, 0x00, 0x3C, 0x00, 
    0x7F, 0x00, 0x3D, 0x00,  0x00, 0x3D, 0x00, 0x00,  0x3D, 0x00, 0x00, 0x3D,  0x00, 0x00, 0x3D, 0x00, 
    0x7F, 0x00, 0x3C, 0x00,  0x00, 0x3C, 0x00, 0x00,  0x3C, 0x00, 0x00, 0x3C,  0x00, 0x00, 0x3C, 0x00, 
    
    SND_CODE_END
  };
  
  static unsigned char data2[] = {
    0x7F, 0x00, 0x36, 0x00,  0x00, 0x36, 0x00, 0x00,  0x36, 0x00, 0x00, 0x36,  0x00, 0x00, 0x36, 0x00,
    0x7F, 0x00, 0x38, 0x00,  0x00, 0x38, 0x00, 0x00,  0x38, 0x00, 0x00, 0x38,  0x00, 0x00, 0x38, 0x00,
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x3A, 0x00, 0x00, 0x3A,  0x00, 0x00, 0x3A, 0x00,
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x38, 0x00, 0x00, 0x38,  0x00, 0x00, 0x38, 0x00,
    
    0x7F, 0x00, 0x36, 0x00,  0x00, 0x36, 0x00, 0x00,  0x36, 0x00, 0x00, 0x36,  0x00, 0x00, 0x36, 0x00,
    0x7F, 0x00, 0x38, 0x00,  0x00, 0x38, 0x00, 0x00,  0x38, 0x00, 0x00, 0x38,  0x00, 0x00, 0x38, 0x00,
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x3A, 0x00, 0x00, 0x3A,  0x00, 0x00, 0x3A, 0x00,
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x38, 0x00, 0x00, 0x38,  0x00, 0x00, 0x38, 0x00,
    
    0x7F, 0x00, 0x36, 0x00,  0x00, 0x36, 0x00, 0x00,  0x36, 0x00, 0x00, 0x36,  0x00, 0x00, 0x36, 0x00,
    0x7F, 0x00, 0x38, 0x00,  0x00, 0x38, 0x00, 0x00,  0x38, 0x00, 0x00, 0x38,  0x00, 0x00, 0x38, 0x00,
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x3A, 0x00, 0x00, 0x3A,  0x00, 0x00, 0x3A, 0x00,
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x38, 0x00, 0x00, 0x38,  0x00, 0x00, 0x38, 0x00,
    
    0x7F, 0x00, 0x36, 0x00,  0x00, 0x36, 0x00, 0x00,  0x36, 0x00, 0x00, 0x36,  0x00, 0x00, 0x36, 0x00,
    0x7F, 0x00, 0x38, 0x00,  0x00, 0x38, 0x00, 0x00,  0x38, 0x00, 0x00, 0x38,  0x00, 0x00, 0x38, 0x00,
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x3A, 0x00, 0x00, 0x3A,  0x00, 0x00, 0x3A, 0x00,
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x38, 0x00, 0x00, 0x38,  0x00, 0x00, 0x38, 0x00,
    
    
    
    0x7F, 0x00, 0x36, 0x00,  0x00, 0x36, 0x00, 0x00,  0x36, 0x00, 0x00, 0x36,  0x00, 0x00, 0x36, 0x00,
    0x7F, 0x00, 0x38, 0x00,  0x00, 0x38, 0x00, 0x00,  0x38, 0x00, 0x00, 0x38,  0x00, 0x00, 0x38, 0x00,
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x3A, 0x00, 0x00, 0x3A,  0x00, 0x00, 0x3A, 0x00,
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x38, 0x00, 0x00, 0x38,  0x00, 0x00, 0x38, 0x00,
    
    0x7F, 0x00, 0x36, 0x00,  0x00, 0x36, 0x00, 0x00,  0x36, 0x00, 0x00, 0x36,  0x00, 0x00, 0x36, 0x00,
    0x7F, 0x00, 0x38, 0x00,  0x00, 0x38, 0x00, 0x00,  0x38, 0x00, 0x00, 0x38,  0x00, 0x00, 0x38, 0x00,
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x3A, 0x00, 0x00, 0x3A,  0x00, 0x00, 0x3A, 0x00,
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x38, 0x00, 0x00, 0x38,  0x00, 0x00, 0x38, 0x00,
    
    //torinouta
    0x7F, 0x00, 0x36, 0x00,  0x00, 0x36, 0x00, 0x00,  0x36, 0x00, 0x00, 0x36,  0x00, 0x00, 0x36, 0x00,
    0x7F, 0x00, 0x38, 0x00,  0x00, 0x38, 0x00, 0x00,  0x38, 0x00, 0x00, 0x38,  0x00, 0x00, 0x38, 0x00,
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x3A, 0x00, 0x00, 0x3A,  0x00, 0x00, 0x3A, 0x00,
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x38, 0x00, 0x00, 0x38,  0x00, 0x00, 0x38, 0x00,
    
    0x7F, 0x00, 0x36, 0x00,  0x00, 0x36, 0x00, 0x00,  0x36, 0x00, 0x00, 0x36,  0x00, 0x00, 0x36, 0x00,
    0x7F, 0x00, 0x38, 0x00,  0x00, 0x38, 0x00, 0x00,  0x38, 0x00, 0x00, 0x38,  0x00, 0x00, 0x38, 0x00,
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x3A, 0x00, 0x00, 0x3A,  0x00, 0x00, 0x3A, 0x00,
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x38, 0x00, 0x00, 0x38,  0x00, 0x00, 0x38, 0x00,
    
    0x7F, 0x00, 0x36, 0x00,  0x00, 0x36, 0x00, 0x00,  0x36, 0x00, 0x00, 0x36,  0x00, 0x00, 0x36, 0x00,
    0x7F, 0x00, 0x38, 0x00,  0x00, 0x38, 0x00, 0x00,  0x38, 0x00, 0x00, 0x38,  0x00, 0x00, 0x38, 0x00,
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x3A, 0x00, 0x00, 0x3A,  0x00, 0x00, 0x3A, 0x00,
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x38, 0x00, 0x00, 0x38,  0x00, 0x00, 0x38, 0x00,
    
    0x7F, 0x00, 0x36, 0x00,  0x00, 0x36, 0x00, 0x00,  0x36, 0x00, 0x00, 0x36,  0x00, 0x00, 0x36, 0x00,
    0x7F, 0x00, 0x38, 0x00,  0x00, 0x38, 0x00, 0x00,  0x38, 0x00, 0x00, 0x38,  0x00, 0x00, 0x38, 0x00,
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x3A, 0x00, 0x00, 0x3A,  0x00, 0x00, 0x3A, 0x00,
    0x7F, 0x00, 0x3A, 0x00,  0x00, 0x3A, 0x00, 0x00,  0x38, 0x00, 0x00, 0x38,  0x00, 0x00, 0x38, 0x00,
    
    SND_CODE_END
  };

  static unsigned char data3[] = {
    0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,
    0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,
    0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,
    0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,
    
    0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,
    0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,
    0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,
    0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,
    
    0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,
    0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,
    0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,
    0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,
    
    0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,
    0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,
    0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,
    0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,
    
    
    
    0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,
    0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,
    0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,
    0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,
    
    0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,
    0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,
    0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,
    0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,
    
    //torinouta
    0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,
    0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,
    0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,
    0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,
    
    0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,
    0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,
    0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,
    0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,
    
    0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,
    0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,
    0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,
    0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,
    
    0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,  0x2A, 0x00, 0x00, 0x00,
    0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,
    0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,  0x2E, 0x00, 0x00, 0x00,
    0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,  0x2C, 0x00, 0x00, 0x00,
    
    SND_CODE_END
  };
  
  static unsigned char data4[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    
    0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 
    0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 
    0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 
    0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 
    
    0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 
    0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 
    0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 
    0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 
    
    0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 
    0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 
    0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 
    0x7F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    
    
    
    0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 
    0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 
    0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 
    0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 
    
    0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 
    0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 
    0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 
    0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 
    
    
    //torinouta
    0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 
    0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 
    0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 
    0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 
    
    0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 
    0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 
    0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 
    0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 
    
    0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 
    0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 
    0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 
    0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 
    
    0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 0x31, 0x3A, 0x2A, 
    0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 
    0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 0x35, 0x3D, 0x2E, 
    0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 0x33, 0x3C, 0x2C, 
    
    SND_CODE_END
  };
  
  static unsigned char data5[] = {
    //intro
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3A, 0x00, 0x00, 0x00, 0x3C, 0x00, 0x3D, 0x00, 0x44, 0x00, //ki-eruhi

    //torinouta
    0x41, 0x00, 0x00, 0x00, 0x41, 0x00, 0x3F, 0x41, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x3F, 0x00, 0x41, 0x00, 0x44, 0x00, 0x3F, 0x00, 0x3C, 0x00, 0x3D, 0x00,
    0x3C, 0x00, 0x00, 0x00, 0x3C, 0x00, 0x3A, 0x35, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3A, 0x00, 0x00, 0x00, 0x3C, 0x00, 0x3D, 0x00, 0x44, 0x00,
    
    0x41, 0x00, 0x00, 0x00, 0x41, 0x00, 0x3F, 0x41, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x3F, 0x00, 0x41, 0x00, 0x44, 0x00, 0x41, 0x00, 0x44, 0x00, 0x49, 0x00,
    0x48, 0x00, 0x00, 0x46, 0x00, 0x00, 0x41, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3F, 0x00, 
    0x41, 0x00, 0x00, 0x00, 0x44, 0x00, 0x00, 0x00, 0x46, 0x00, 0x00, 0x00, 0x48, 0x00, 0x00, 0x00,
    
    0x41, 0x00, 0x00, 0x00, 0x41, 0x00, 0x3F, 0x41, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x3F, 0x00, 0x41, 0x00, 0x44, 0x00, 0x3F, 0x00, 0x3C, 0x00, 0x3D, 0x00,
    0x3C, 0x00, 0x00, 0x00, 0x3C, 0x00, 0x3A, 0x35, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3A, 0x00, 0x00, 0x00, 0x3C, 0x00, 0x3D, 0x00, 0x44, 0x00,
    
    0x41, 0x00, 0x00, 0x00, 0x41, 0x00, 0x3F, 0x41, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x3F, 0x00, 0x41, 0x00, 0x44, 0x00, 0x41, 0x00, 0x44, 0x00, 0x49, 0x00,
    0x48, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x46, 0x00, 
    0x46, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    
    //senmeri
    0x3F, 0x00, 0x41, 0x00, 0x3F, 0x00, 0x3A, 0x00, 0x3F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x3F, 0x00, 0x41, 0x00, 0x3F, 0x00, 0x41, 0x00, 0x44, 0x00, 0x41, 0x00,
    0x3F, 0x00, 0x41, 0x00, 0x3F, 0x00, 0x3A, 0x00, 0x3D, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x49, 0x00, 0x00, 0x00, 0x48, 0x00, 0x44, 0x00, 0x41, 0x00, 0x00, 0x00,

    0x3F, 0x00, 0x41, 0x00, 0x3F, 0x00, 0x3A, 0x00, 0x3F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x3F, 0x00, 0x41, 0x00, 0x3F, 0x00, 0x41, 0x00, 0x44, 0x00, 0x41, 0x00,
    0x3F, 0x00, 0x41, 0x00, 0x3F, 0x00, 0x3D, 0x00, 0x3A, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3A, 0x00, 0x00, 0x00, 0x3C, 0x00, 0x3D, 0x00, 0x44, 0x00, //ki-eruhi
    
    
    ////higu
    //0x3F, 0x00, 0x00, 0x00, 0x41, 0x3F, 0x3D, 0x00, 0x3F, 0x00, 0x38, 0x00, 0x41, 0x3F, 0x3D, 0x00, 
    //0x3F, 0x00, 0x38, 0x00, 0x41, 0x3F, 0x3D, 0x00, 0x3D, 0x00, 0x44, 0x00, 0x3F, 0x00, 0x00, 0x00, 
    //0x3F, 0x00, 0x00, 0x00, 0x41, 0x3F, 0x3D, 0x00, 0x3F, 0x00, 0x38, 0x00, 0x41, 0x3F, 0x3D, 0x00, 
    //0x3F, 0x00, 0x38, 0x00, 0x41, 0x3F, 0x3D, 0x00, 0x3D, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    SND_CODE_END
  };
  
  static unsigned char data10[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,  
    
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x28, 0x00, 
    
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x28, 0x28,  
    
    
    
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x28, 0x28, 0x28,
    
    //torinouta
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x28, 0x28, 0x28,
    
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 
    0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x28, 0x28, 0x28, 0x28,
    
    SND_CODE_END
  };
  
  static unsigned char data11[] = {
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
    
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x40,
    
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x40, 
    
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x40, 0x40, 0x40, 

    
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x40,
    
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x40, 0x40, 0x40, 
    
    //torinouta
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x40, 0x40, 0x40, 
    
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x40, 0x40, 0x40, 
    
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x40, 0x40, 0x40, 
    
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00,
    0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x40, 0x40, 0x40, 
    
    SND_CODE_END
  };
  
  printf("ALLOC = %d kbyte\n", sizeof(canvas) / 1024);
  printf("SND_UNIT_NUM = %d\n", SND_UNIT_NUM);

  /*
  snd_render_track(2,  data1, 0.052, 1.0, 0.8); //cho1
  snd_render_track(2,  data2, 0.052, 1.0, 0.8); //cho2
  snd_render_track(2,  data3, 0.052, 0.9, 1.0); //bas1
  snd_render_track(3,  data4, 0.07,  1.0, 0.8); //osuth
  
  snd_render_track(1,  data5, 0.08,  1.0, 1.0); //mel
  snd_render_track(10, data10, 0.32,  0.9, 1.0); //bd
  snd_render_track(11, data11, 0.32,  0.9, 1.0); //sd
  
  */
  
  int i = 0;
  for(float detune = 0.997f; detune <= 1.004f; detune += 0.002f) {
    i++;
    printf("detune = %f\n", detune);
    snd_render_track(2,  data1,  0.052, 0.8, 0.7, detune); //cho1
    snd_render_track(2,  data2,  0.052, 0.8, 0.7, detune); //cho2
    snd_render_track(2,  data3,  0.052, 0.8, 0.7, detune); //bas1
    snd_render_track(3,  data4,  0.06,  0.8, 1.0, detune); //osuth
    
    snd_render_track(1,  data5,  0.07,  1.0, 1.0, detune); //mel
    snd_render_track(10, data10, 0.22,  0.8, 1.0, detune); //bd
    snd_render_track(11, data11, 0.22,  0.7, 1.0, detune); //sd
  }
  
  snd_global_vol(1.0 / (float)(i));
  
  snd_play();
  MessageBox(NULL,TEXT("ՂꂢȂ : OKƏI܂B\nĐIOKďIĂB"), TEXT("Wave"),MB_OK);
  snd_term();
  return 0;
}


